@@ -19,9 +19,13 @@ from django.conf import settings
 from django.core import management
 from django.core.files import File
 from django.core.files.storage import Storage
+from django.core.validators import MinValueValidator
 from django.db import connection
 from django.db import models
+from django.db.models import CheckConstraint
 from django.db.models import Count
+from django.db.models import F
+from django.db.models import Q
 from django.db.models import Sum
 from django.utils.module_loading import import_string
 from django.utils.translation import gettext_lazy as _
@@ -88,8 +92,12 @@ def check_response(response) -> None:
     This method checks if responses have an error, and raise a readable
     message.
     """
-    if response.Errors:
-        raise exceptions.AfipException(response)
+    if "Errors" in response:
+        if response.Errors:
+            raise exceptions.AfipException(response)
+    elif "errorConstancia" in response:
+        if response.errorConstancia:
+            raise exceptions.AfipException(response)
 
 
 def first_currency() -> int | None:
@@ -499,14 +507,17 @@ class TaxPayer(models.Model):
         """
         return self.get_ticket(service) or self.create_ticket(service)
 
-    def fetch_points_of_sales(self, ticket: AuthTicket = None) -> list[PointOfSales]:
+    def fetch_points_of_sales(
+        self,
+        ticket: AuthTicket = None,
+    ) -> list[tuple[PointOfSales, bool]]:
         """
         Fetch all point of sales objects.
 
         Fetch all point of sales from the WS and store (or update) them
         locally.
 
-        Returns a list of tuples with the format (pos, created,).
+        Returns a list of tuples with the format ``(pos, created,)``.
         """
         ticket = ticket or self.get_or_create_ticket("wsfe")
 
@@ -805,6 +816,7 @@ class ReceiptQuerySet(models.QuerySet):
         doing!
         """
         first = self.select_related("point_of_sales", "receipt_type").first()
+        assert first is not None  # should never happen; mostly a hint for mypy
 
         next_num = (
             Receipt.objects.fetch_last_receipt_number(
@@ -897,6 +909,7 @@ class ReceiptQuerySet(models.QuerySet):
 
     def _validate(self, ticket=None) -> list[str]:
         first = self.first()
+        assert first is not None  # should never happen; mostly a hint for mypy
         ticket = ticket or first.point_of_sales.owner.get_or_create_ticket("wsfe")
         client = clients.get_client("wsfe", first.point_of_sales.owner.is_sandboxed)
         response = client.service.FECAESolicitar(
@@ -1255,6 +1268,8 @@ class Receipt(models.Model):
         # This may avoid unnecessary revalidation
         if self.is_validated:
             return self.validation
+        if not self.receipt_number:
+            return None
 
         receipt_data = Receipt.objects.fetch_receipt_data(
             self.receipt_type.code, self.receipt_number, self.point_of_sales
@@ -1275,7 +1290,7 @@ class Receipt(models.Model):
             )
             if receipt_data.Observaciones:
                 for obs in receipt_data.Observaciones.Obs:
-                    observation = Observation.objects.get_or_create(
+                    observation, _ = Observation.objects.get_or_create(
                         code=obs.Code,
                         message=obs.Msg,
                     )
@@ -1493,6 +1508,14 @@ class ReceiptEntry(models.Model):
         decimal_places=2,
         help_text=_("Price per unit before vat or taxes."),
     )
+    discount = models.DecimalField(
+        _("discount"),
+        max_digits=15,
+        decimal_places=2,
+        default=0,
+        help_text=_("Total net discount applied to row's total."),
+        validators=[MinValueValidator(Decimal("0.0"))],
+    )
     vat = models.ForeignKey(
         VatType,
         related_name="receipt_entries",
@@ -1503,13 +1526,22 @@ class ReceiptEntry(models.Model):
     )
 
     @property
-    def total_price(self) -> int:
-        """The total price for this line (quantity * price)."""
-        return self.quantity * self.unit_price
+    def total_price(self) -> Decimal:
+        """The total price for this entry is: ``quantity * price - discount``."""
+        return self.quantity * self.unit_price - self.discount
 
     class Meta:
         verbose_name = _("receipt entry")
         verbose_name_plural = _("receipt entries")
+        constraints = [
+            CheckConstraint(
+                check=Q(discount__gte=Decimal("0.0")), name="discount_positive_value"
+            ),
+            CheckConstraint(
+                check=Q(discount__lte=F("quantity") * F("unit_price")),
+                name="discount_less_than_total",
+            ),
+        ]
 
 
 class Tax(models.Model):
@@ -1546,7 +1578,7 @@ class Tax(models.Model):
         on_delete=models.PROTECT,
     )
 
-    def compute_amount(self) -> int:
+    def compute_amount(self) -> Decimal:
         """Auto-assign and return the total amount for this tax."""
         self.amount = self.base_amount * self.aliquot / 100
         return self.amount
